@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+import json
 import logging
 import requests
 import socket
@@ -24,6 +25,10 @@ API_GET_ATHENA_DATABASES = "/get_athena_databases"
 API_GET_ATHENA_TABLES = "/get_athena_tables"
 API_QUERY_ATHENA_TABLE = "/query_athena_table"
 API_RUN_QUERY_ON_ATHENA = "/run_query_on_athena"
+HEADERS = {
+    'content-type': "application/json",
+    'cache-control': "no-cache",
+}
 
 
 # TODO - Add user validation
@@ -41,8 +46,8 @@ class AthenaClient:
     def databases(self):
         """Returns all the schemas available in Athena"""
         try:
-            pay_load = {"user_name": self._user_name, "password": self._password}
-            r = requests.post(SERVICE_URL + API_GET_ATHENA_DATABASES, data=pay_load)
+            payload = json.dumps({"user_name": self._user_name, "password": self._password})
+            r = requests.post(SERVICE_URL + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS)
             response = r.json()
             return response
         except requests.exceptions.HTTPError as err_h:
@@ -57,8 +62,8 @@ class AthenaClient:
     def tables(self, schema_name):
         """Returns all the tables present in a schema"""
         try:
-            pay_load = {"user_name": self._user_name, "password": self._password, "schema_name": schema_name}
-            r = requests.post(SERVICE_URL + API_GET_ATHENA_TABLES, data=pay_load)
+            payload = json.dumps({"user_name": self._user_name, "password": self._password, "schema_name": schema_name})
+            r = requests.post(SERVICE_URL + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS)
             response = r.json()
             return response
         except requests.exceptions.HTTPError as err_h:
@@ -73,9 +78,9 @@ class AthenaClient:
     def top(self, schema_name, table_name, limit=None):
         """Returns records from a table"""
         try:
-            pay_load = {"user_name": self._user_name, "password": self._password, "schema_name": schema_name,
-                        "table_name": table_name, "limit": limit}
-            r = requests.post(SERVICE_URL + API_QUERY_ATHENA_TABLE, data=pay_load)
+            payload = json.dumps({"user_name": self._user_name, "password": self._password, "schema_name": schema_name,
+                                  "table_name": table_name, "limit": limit})
+            r = requests.post(SERVICE_URL + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS)
             response = r.json()
             return response
         except requests.exceptions.HTTPError as err_h:
@@ -90,9 +95,10 @@ class AthenaClient:
     def run_query(self, query_string, result_as_df=True):
         """Run a specified query"""
         try:
-            pay_load = {"user_name": self._user_name, "password": self._password, "query_string": query_string,
-                        "result_as_df": result_as_df}
-            r = requests.post(SERVICE_URL + API_RUN_QUERY_ON_ATHENA, data=pay_load)
+            payload = json.dumps(
+                {"user_name": self._user_name, "password": self._password, "query_string": query_string,
+                 "result_as_df": result_as_df})
+            r = requests.post(SERVICE_URL + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS)
             response = r.json()
             if result_as_df:
                 response_as_df = pd.DataFrame.from_dict(response, orient="index")
